@@ -91,8 +91,8 @@ def get_minimal_inconsistent_cores(instance,nmodels=0,exclude=[]):
     '''
     inputs = get_reductions(instance)
     prg = [ dyn_mic_prg, inputs.to_file(), instance.to_file(), exclude_sol(exclude) ] 
-    options=' --heuristic=Vmtf'
-    solver = GringoClaspD(options)
+    options='--heuristic=Vmtf'
+    solver = GringoClaspD(clasp_options=options)
     models = solver.run(prg,nmodels=0,collapseTerms=True, collapseAtoms=False)
     os.unlink(prg[1])
     os.unlink(prg[2])
